﻿using UnityEngine;
using UnityEngine.UI;
using System.Collections;

public class ClockScript : MonoBehaviour {

    public Image MinTen, MinOne, SecTen, SecOne;    // images for the pixelated number sprites

    public AudioClip tapNoise;

    private Sprite[] _digitSprites; // array of sprites for 0-9 and :
    private float _timerStart;      // time that the timer was started
    private bool _timing = false;   // true if actively keeping time
    private AudioSource _audio;

    private int _nSeconds;
    public  int numSeconds {    // integer number of seconds since timing began
        get { return _nSeconds; }
        private set {
            _nSeconds = value;
            // adjust the images on the clock to match the time
            if (_nSeconds > ((100 * 60) - 1)) { // clamp @ highest displayable second
                _nSeconds = ((100 * 60) - 1);
            }
            int minutes = _nSeconds / 60;
            MinTen.sprite = _digitSprites[minutes / 10];
            MinOne.sprite = _digitSprites[minutes % 10];
            int seconds = _nSeconds % 60;
            SecTen.sprite = _digitSprites[seconds / 10];
            SecOne.sprite = _digitSprites[seconds % 10];
        }
    }

    void Awake() {
        _digitSprites = Resources.LoadAll<Sprite>("digits");
        _audio = GetComponent<AudioSource>();
    }

	void Start () {
        numSeconds = 0;
	}
	
	void Update () {
	    if (_timing) {
            // counting up the seconds since the timer began
            if ((Time.time - _timerStart) > numSeconds + 1) {
                numSeconds++;
            }
        } else {
            // not timing; instead blinks current value
            if (((int)Time.time & 1) == 0) {
                MinTen.color = Color.red;
                MinOne.color = Color.red;
                SecTen.color = Color.red;
                SecOne.color = Color.red;
            } else {
                MinTen.color = Color.clear;
                MinOne.color = Color.clear;
                SecTen.color = Color.clear;
                SecOne.color = Color.clear;
            }

        }
	}

    // Begin timing NOW
    public void StartClock() {
        numSeconds = 0;
        _timerStart = Time.time;
        _timing = true;
        MinTen.color = Color.red;
        MinOne.color = Color.red;
        SecTen.color = Color.red;
        SecOne.color = Color.red;
    }

    public void StopClock() {
        _timing = false;
    }

    public void OnMouseDown() {
        _audio.PlayOneShot(tapNoise);
        _timerStart--;
    }
}
