using UnityEngine;
using System.Collections;

public class HoleScript : MonoBehaviour {

    public Color LitColor;      // light color when position is a valid move
    public Color SublitColor;   // light color when position is a potential move for a peg

    public Point point;             // this hole's location (see Point.cs)
    public PegScript peg = null;    // attached peg to this location (can be null)
    public bool validMove = false;  // enabled by a Selected Peg if this is a potential end location

    public bool IsOccupied {    // shorthand for a null check on the peg
        get { return (peg == null ? false : true); }
    }

    private BoardScript _board;
    private Light _light;

    private bool _sublit;   // switch for pulsing light on potential move

    void Start() {
        _board = transform.parent.GetComponent<BoardScript>();
        _light = transform.GetChild(1).GetComponent<Light>();
        _light.gameObject.SetActive(false);
    }

    void Update() {
        if (_sublit) {
            // subtle pulsation of sublighting
            _light.intensity = .6f + (Mathf.Sin(Time.time * 4f) / 5);
        }
    }


    void OnMouseEnter() {
        // turn on glow when hovering w/ valid peg
        if (!IsOccupied && validMove) {
            _light.color = LitColor;
            _light.intensity = 1f;
            _light.gameObject.SetActive(true);
        }
    }

    void OnMouseExit() {
        _light.gameObject.SetActive(false);
    }

    void OnMouseDown() {
        // if clicked & valid move for peg, move peg to this position
        if (!IsOccupied) {
            if (_board.selectedPeg != null && validMove) {
                // can move here!
                _board.hasControl = false;
                _board.selectedPeg.JumpTo(this);
                _light.gameObject.SetActive(false);
            }
        }
    }

    // used to indicate that a peg has a valid move to this hole
    // (turns off/on the light)
    public void SetSublight(bool on) {
        if (on) {
            _light.color = SublitColor;
            _light.gameObject.SetActive(true);
        } else {
            _light.gameObject.SetActive(false);
        }
        _sublit = on;
    }
}
